@@ -1,9 +1,8 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Mito.
-# Distributed under the terms of the Modified BSD License.
-
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
 """
 Contains functions for upgrading analyses!
 
@@ -27,9 +26,9 @@ from mitosheet.saved_analyses.step_upgraders.change_column_dtype import \
 from mitosheet.saved_analyses.step_upgraders.delete_column import (
     upgrade_delete_column_1_to_2, upgrade_delete_column_2_to_3)
 from mitosheet.saved_analyses.step_upgraders.filter import (
-    update_filter_column_1_to_filter_column_2, upgrade_filter_column_2_to_3)
+    update_filter_column_1_to_filter_column_2, upgrade_filter_column_2_to_3, upgrade_filter_column_3_to_4)
 from mitosheet.saved_analyses.step_upgraders.merge import (
-    upgrade_merge_1_to_merge_2, upgrade_merge_2_to_3)
+    upgrade_merge_1_to_merge_2, upgrade_merge_2_to_3, upgrade_merge_3_to_4)
 from mitosheet.saved_analyses.step_upgraders.pivot import (
     upgrade_group_1_to_pivot_2, upgrade_pivot_2_to_pivot_3,
     upgrade_pivot_3_to_4, upgrade_pivot_4_to_5_and_rename, upgrade_pivot_5_to_6)
@@ -42,6 +41,7 @@ from mitosheet.saved_analyses.step_upgraders.set_column_formula import \
 from mitosheet.saved_analyses.step_upgraders.simple_import import \
     upgrade_simple_import_1_to_2_and_rename
 from mitosheet.saved_analyses.step_upgraders.sort import upgrade_sort_1_to_2
+from mitosheet.saved_analyses.step_upgraders.graph import upgrade_graph_1_to_2, upgrade_graph_2_to_3, upgrade_graph_3_to_4
 from mitosheet.saved_analyses.step_upgraders.utils_rename_column_headers import (INITIAL_BULK_OLD_RENAME_STEP)
 
 """
@@ -80,7 +80,8 @@ STEP_UPGRADES_FUNCTION_MAPPING_NEW_FORMAT = {
     },
     'merge': {
         1: upgrade_merge_1_to_merge_2,
-        2: upgrade_merge_2_to_3
+        2: upgrade_merge_2_to_3,
+        3: upgrade_merge_3_to_4,
     },
     'change_column_dtype': {
         1: upgrade_change_column_dtype_1_to_2
@@ -90,7 +91,8 @@ STEP_UPGRADES_FUNCTION_MAPPING_NEW_FORMAT = {
         2: upgrade_delete_column_2_to_3
     },
     'filter_column': {
-        2: upgrade_filter_column_2_to_3
+        2: upgrade_filter_column_2_to_3,
+        3: upgrade_filter_column_3_to_4
     },
     'pivot': {
         3: upgrade_pivot_3_to_4,
@@ -108,6 +110,11 @@ STEP_UPGRADES_FUNCTION_MAPPING_NEW_FORMAT = {
     },
     'sort': {
         1: upgrade_sort_1_to_2
+    },
+    'graph': {
+        1: upgrade_graph_1_to_2,
+        2: upgrade_graph_2_to_3,
+        3: upgrade_graph_3_to_4
     }
 }
 
@@ -128,8 +135,10 @@ def should_add_initial_bulk_old_rename_step(version: str) -> bool:
     elif package_name == 'mitosheet3':
         if is_prev_version(version, '0.3.130'):
             return True
-    else: 
-        raise Exception('Invalid package name', package_name)
+    elif package_name == 'mitosheet2':
+        # Because mitosheet2 was introduced so much later than this upgrade,
+        # we always return false here
+        return False
 
     return False
 
