@@ -30,10 +30,6 @@ class AddColumnStepPerformer(StepPerformer):
     def step_type(cls) -> str:
         return 'add_column'
 
-    @classmethod
-    def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
-        return params
-
     @classmethod
     def execute(cls, prev_state: State, params: Dict[str, Any]) -> Tuple[State, Optional[Dict[str, Any]]]:
         sheet_index: int = get_param(params, 'sheet_index')
@@ -55,10 +51,7 @@ class AddColumnStepPerformer(StepPerformer):
             column_header_index = len(prev_state.dfs[sheet_index].columns)
 
         # Update the state variables
-        column_id = post_state.column_ids.add_column_header(sheet_index, column_header)
-        post_state.column_spreadsheet_code[sheet_index][column_id] = '=0'
-        post_state.column_filters[sheet_index][column_id] = {'operator': 'And', 'filters': []}
-        post_state.column_format_types[sheet_index][column_id] = {'type': FORMAT_DEFAULT}
+        post_state.add_columns_to_state(sheet_index, [column_header])
             
         # Update the dataframe
         pandas_start_time = perf_counter()
@@ -83,11 +76,5 @@ class AddColumnStepPerformer(StepPerformer):
         ]
 
     @classmethod
-    def get_modified_dataframe_indexes( # type: ignore
-        cls, 
-        sheet_index: int,
-        column_header: str,
-        column_header_index: int,
-        **params
-    ) -> Set[int]:
-        return {sheet_index}
\ No newline at end of file
+    def get_modified_dataframe_indexes(cls, params: Dict[str, Any]) -> Set[int]:
+        return {get_param(params, 'sheet_index')}
\ No newline at end of file
